# Characters_Sn
Functions for calculation group characters of the symmetric group Sn


This code was written by Lizzie Hernandez 
for Math 68 Algebraic Combinatorics course in Fall 2021 
at Darmouth College 

[GitHub Link] (https://github.com/lizziehv/math68-final)
[Google Colab Link] (https://colab.research.google.com/drive/1GMeXdseX97ZfMtfsO6Tvf5pijP4Zslc6?usp=sharing)